{
  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
    flake-utils.url = "github:numtide/flake-utils";
  };

  outputs = { nixpkgs, flake-utils, ... }:
    flake-utils.lib.eachDefaultSystem (system:
      let
        pkgs = nixpkgs.legacyPackages.${system};

        pnpm = "${pkgs.nodePackages.pnpm}/bin/pnpm";
        biome = "${pkgs.biome}/bin/biome";
      in
      {
        # TODO: add `apps` target to build the bundle using Vite

        formatter = pkgs.writeShellScriptBin "biome-fmt" ''
          ${biome} check --apply .
        '';

        checks = with pkgs; {
          stylelint = writeShellScriptBin "stylelint" ''
            ${pnpm} stylelint src/css/*.scss
          '';
          biome = writeShellScriptBin "biome-check" ''
            ${biome} check .
          '';
        };

        devShells.default = with pkgs; mkShellNoCC {
          name = "docs-ui";
          packages = [
            nodePackages.nodejs
            nodePackages.pnpm
            biome
          ];
        };
      }
    );
}
